@@ -1,4 +1,8 @@
 # -*- coding:utf-8 -*-
+from __future__ import unicode_literals
+from future.builtins import str
+from future.builtins import zip
+from future.builtins import object
 
 from itertools import islice, chain
 from collections import namedtuple
@@ -124,7 +128,7 @@ class ExtendedCollectionManager(CollectionManager):
                                'stored at a key that does not exist anymore.')
 
         for set_ in sets:
-            if isinstance(set_, basestring):
+            if isinstance(set_, str):
                 all_sets.add(set_)
             elif isinstance(set_, ExtendedFilter):
                 # We have a RedisModel and we'll use its pk, or a RedisField
@@ -193,7 +197,7 @@ class ExtendedCollectionManager(CollectionManager):
             elif isinstance(set_, MultiValuesField) and not getattr(set_, '_instance', None):
                 raise ValueError('%s passed to "intersect" must be bound'
                                  % set_.__class__.__name__)
-            elif not isinstance(set_, (tuple, basestring, MultiValuesField, _StoredCollection)):
+            elif not isinstance(set_, (tuple, str, MultiValuesField, _StoredCollection)):
                 raise ValueError('%s is not a valid type of argument that can '
                                  'be used as a set. Allowed are: string (key '
                                  'of a redis set), limpyd multi-values field ('
@@ -282,7 +286,7 @@ class ExtendedCollectionManager(CollectionManager):
             by = parameters.get('by_score', None)
             if isinstance(by, SortedSetField) and getattr(by, '_instance', None):
                 by = by.key
-            elif not isinstance(by, basestring):
+            elif not isinstance(by, str):
                 by = None
 
             if by is None:
@@ -435,8 +439,7 @@ class ExtendedCollectionManager(CollectionManager):
         """
         result = zip(*([iter(collection)] * len(self._values['fields']['names'])))
         if self._values['mode'] == 'dicts':
-            result = [dict(zip(self._values['fields']['names'], a_result))
-                                                for a_result in result]
+            result = (dict(zip(self._values['fields']['names'], a_result)) for a_result in result)
         return result
 
     @property
@@ -445,7 +448,8 @@ class ExtendedCollectionManager(CollectionManager):
         Return True if we have to sort by set and do the stuff *before* asking
         redis for the sort
         """
-        return self._sort_by_sortedset and self._slice and (not self._lazy_collection['pks'] or self._want_score_value)
+        return self._sort_by_sortedset and self._slice and (not self._lazy_collection['pks']
+                                                            or self._want_score_value)
 
     @property
     def _sort_by_sortedset_after(self):
@@ -453,7 +457,8 @@ class ExtendedCollectionManager(CollectionManager):
         Return True if we have to sort by set and do the stuff *after* asking
         redis for the sort
         """
-        return self._sort_by_sortedset and not self._slice and (not self._lazy_collection['pks'] or self._want_score_value)
+        return self._sort_by_sortedset and not self._slice and (not self._lazy_collection['pks']
+                                                                or self._want_score_value)
 
     @property
     def _want_score_value(self):
@@ -537,13 +542,14 @@ class ExtendedCollectionManager(CollectionManager):
         """
         string_filters = filters.copy()
 
-        for field_name, value in filters.iteritems():
+        for field_name, value in filters.items():
 
             is_extended = False
 
             if isinstance(value, RedisField):
                 # we will fetch the value when running the collection
-                if not isinstance(value, SingleValueField) or getattr(value, '_instance', None) is None:
+                if (not isinstance(value, SingleValueField)
+                    or getattr(value, '_instance', None) is None):
                     raise ValueError('If a field is used as a filter value, it '
                                      'must be a simple value field attached to '
                                      'an instance')
@@ -749,7 +755,7 @@ class ExtendedCollectionManager(CollectionManager):
         flat = kwargs.pop('flat', False)
         if kwargs:
             raise ValueError('Unexpected keyword arguments for the values method: %s'
-                             % (kwargs.keys(),))
+                             % list(kwargs))
 
         if not fields:
             fields = self._get_simple_fields()
